@@ -1,18 +1,7 @@
 /*
- * Copyright 2016 ROSA
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2016 ROSA
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef IMAGEWRITER_H
 #define IMAGEWRITER_H
@@ -31,7 +20,7 @@ class ImageWriter : public QObject
     Q_OBJECT
 
 public:
-    explicit ImageWriter(const QString& ImageFile, UsbDevice* Device, QObject *parent = 0);
+    explicit ImageWriter(const QString& ImageFile, UsbDevice* Device, QObject *parent = nullptr);
 
 protected:
     // Information about the selected USB flash disk
@@ -52,8 +41,8 @@ signals:
     void error(QString msg);
     // Emitted when processed the cancel request from user
     void cancelled();
-    // Emitted each time a block is written, <count> is a number of DEFAULT_UNIT-size blocks
-    void blockWritten(int count);
+    // Emitted as the progress percentage changes
+    void progressChanged(int percent);
 
 public slots:
     // The main method that writes the image
